==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/TLSProfileSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface TLSProfileSpecFluent<A extends TLSProfileSpecFluent<A>> extends Fluent<A>{
  public A addToCiphers(Integer index,String item);
  public A setToCiphers(Integer index,String item);
  public A addToCiphers(java.lang.String... items);
  public A addAllToCiphers(Collection<String> items);
  public A removeFromCiphers(java.lang.String... items);
  public A removeAllFromCiphers(Collection<String> items);
  public List<String> getCiphers();
  public String getCipher(Integer index);
  public String getFirstCipher();
  public String getLastCipher();
  public String getMatchingCipher(Predicate<String> predicate);
  public Boolean hasMatchingCipher(Predicate<String> predicate);
  public A withCiphers(List<String> ciphers);
  public A withCiphers(java.lang.String... ciphers);
  public Boolean hasCiphers();
  public String getMinTLSVersion();
  public A withMinTLSVersion(String minTLSVersion);
  public Boolean hasMinTLSVersion();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/TLSProfileSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TLSProfileSpecFluent<A extends TLSProfileSpecFluent<A>> extends Fluent<A>{
  public A addToCiphers(int index,String item);
  public A setToCiphers(int index,String item);
  public A addToCiphers(java.lang.String... items);
  public A addAllToCiphers(Collection<String> items);
  public A removeFromCiphers(java.lang.String... items);
  public A removeAllFromCiphers(Collection<String> items);
  public List<String> getCiphers();
  public String getCipher(int index);
  public String getFirstCipher();
  public String getLastCipher();
  public String getMatchingCipher(Predicate<String> predicate);
  public Boolean hasMatchingCipher(Predicate<String> predicate);
  public A withCiphers(List<String> ciphers);
  public A withCiphers(java.lang.String... ciphers);
  public Boolean hasCiphers();
  public String getMinTLSVersion();
  public A withMinTLSVersion(String minTLSVersion);
  public Boolean hasMinTLSVersion();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
